Package 'aichicities'

Title: Aichi Prefecture administrative district data
Description: This package provides administrative district data of Aichi Prefecture, Japan.
Authors: Keisuke ANDO [aut, cre]
Maintainer: Keisuke ANDO <[email protected]>
License: CC BY 4.0
Version: 0.1.0
Built: 2026-05-28 10:52:59 UTC
Source: https://github.com/NONONOexe/aichicities

Help Index


Aichi prefecture administrative district data

Description

Information on administrative areas such as cities and wards in Aichi prefecture.

Usage

aichi_districts

Format

Each is a tibble with 69 rows 6 variables:

city

City names

city_code

City codes

city_kanji

City names in japanese

geom

Geometry data (polygon or multi-polygon type) of boundaries

Examples

aichi_districts

Download the Aichi Prefecture administrative district data

Description

Download the Aichi Prefecture administrative district data provided by the Ministry of Land, Infrastructure, Transport and Tourism.

Usage

download_aichi_district_data(download_dir = getwd())

Arguments

download_dir

A directory where downloaded file is to saved.

Value

Path of the downloaded file (invisibly).

Examples

## Not run: 
download_aichi_district_data("download-dir-path")

## End(Not run)

Find district by city name

Description

The function returns the districts of the specified city name. The search is performed with partial matches.

The function returns the districts of the specified city name. The search is performed with partial matches.

Usage

find_districts(city_name)

find_districts(city_name)

Arguments

city_name

Part of the city name

Value

districts of the specified city name

districts of the specified city name

Examples

## Not run: 
toyota_districts <- find_districts("Toyota-shi")

## End(Not run)
## Not run: 
toyota_districts <- find_districts("Toyota-shi")

## End(Not run)

Read the Aichi Prefecture administrative district data

Description

Read the Aichi Prefecture administrative district data.

Usage

read_aichi_district_data(file)

Arguments

file

A file path of data to read.

Format

Each is a tibble with 69 rows 6 variables:

city

City names

city_code

City codes

city_kanji

City names in japanese

geom

Geometry data (polygon or multi-polygon type) of boundaries

Value

Information on administrative areassuch as cities and wards in Aichi prefecture.

Examples

## Not run: 
aichi_districts <- read_aichi_district_data("N03-20210101_23_GML.zip")

## End(Not run)