| Title: | Aichi Prefecture administrative district data |
|---|---|
| Description: | This package provides administrative district data of Aichi Prefecture, Japan. |
| Authors: | Keisuke ANDO [aut, cre] |
| Maintainer: | Keisuke ANDO <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.1.0 |
| Built: | 2026-05-28 10:52:59 UTC |
| Source: | https://github.com/NONONOexe/aichicities |
Information on administrative areas such as cities and wards in Aichi prefecture.
aichi_districtsaichi_districts
Each is a tibble with 69 rows 6 variables:
City names
City codes
City names in japanese
Geometry data (polygon or multi-polygon type) of boundaries
aichi_districtsaichi_districts
Download the Aichi Prefecture administrative district data provided by the Ministry of Land, Infrastructure, Transport and Tourism.
download_aichi_district_data(download_dir = getwd())download_aichi_district_data(download_dir = getwd())
download_dir |
A directory where downloaded file is to saved. |
Path of the downloaded file (invisibly).
## Not run: download_aichi_district_data("download-dir-path") ## End(Not run)## Not run: download_aichi_district_data("download-dir-path") ## End(Not run)
The function returns the districts of the specified city name. The search is performed with partial matches.
The function returns the districts of the specified city name. The search is performed with partial matches.
find_districts(city_name) find_districts(city_name)find_districts(city_name) find_districts(city_name)
city_name |
Part of the city name |
districts of the specified city name
districts of the specified city name
## Not run: toyota_districts <- find_districts("Toyota-shi") ## End(Not run) ## Not run: toyota_districts <- find_districts("Toyota-shi") ## End(Not run)## Not run: toyota_districts <- find_districts("Toyota-shi") ## End(Not run) ## Not run: toyota_districts <- find_districts("Toyota-shi") ## End(Not run)
Read the Aichi Prefecture administrative district data.
read_aichi_district_data(file)read_aichi_district_data(file)
file |
A file path of data to read. |
Each is a tibble with 69 rows 6 variables:
City names
City codes
City names in japanese
Geometry data (polygon or multi-polygon type) of boundaries
Information on administrative areassuch as cities and wards in Aichi prefecture.
## Not run: aichi_districts <- read_aichi_district_data("N03-20210101_23_GML.zip") ## End(Not run)## Not run: aichi_districts <- read_aichi_district_data("N03-20210101_23_GML.zip") ## End(Not run)